package com.engine.organization.initdata;

import com.engine.organization.entity.company.po.CompPO;
import com.engine.organization.entity.department.po.DepartmentPO;
import com.engine.organization.entity.job.po.JobPO;
import com.engine.organization.mapper.comp.CompMapper;
import com.engine.organization.mapper.department.DepartmentMapper;
import com.engine.organization.mapper.job.JobMapper;
import com.engine.organization.thread.CompanyTriggerRunnable;
import com.engine.organization.thread.DepartmentTriggerRunnable;
import com.engine.organization.thread.HrmResourceTriggerRunnable;
import com.engine.organization.thread.JobTriggerRunnable;
import com.engine.organization.util.db.MapperProxyFactory;
import weaver.conn.RecordSet;

import java.util.Set;

/**
 * @author:dxfeng
 * @createTime: 2022/11/07
 * @version: 1.0
 */
public class RefreshPlan {

    private static JobMapper getJobMapper() {
        return MapperProxyFactory.getProxy(JobMapper.class);
    }

    private static CompMapper getCompMapper() {
        return MapperProxyFactory.getProxy(CompMapper.class);
    }

    private static DepartmentMapper getDepartmentMapper() {
        return MapperProxyFactory.getProxy(DepartmentMapper.class);
    }

    // 递归刷新岗位
    public static void refreshJob(Long parentJobId, Set<Long> jobSet) {
        if (null == parentJobId || jobSet.contains(parentJobId)) {
            return;
        }
        // 获取父级岗位、同步数据
        JobPO jobById = getJobMapper().getJobById(parentJobId);
        if (null != jobById) {
            updateResourceJob(parentJobId);
            new JobTriggerRunnable(jobById, jobById).run();
            refreshJob(jobById.getParentJob(), jobSet);
        }
        jobSet.add(parentJobId);
    }

    // 递归刷新部门
    public static void refreshDepartment(Long parentDepartmentId, Set<Long> departmentSet) {
        if (null == parentDepartmentId || departmentSet.contains(parentDepartmentId)) {
            return;
        }
        // 获取父级岗位、同步数据
        DepartmentPO deptById = getDepartmentMapper().getDeptById(parentDepartmentId);
        if (null != deptById) {
            new DepartmentTriggerRunnable(deptById, deptById).run();
            refreshDepartment(deptById.getParentDept(), departmentSet);
        }
        departmentSet.add(parentDepartmentId);
    }

    public static void refreshCompany(Long parentCompanyId, Set<Long> companySet) {
        if (null == parentCompanyId || companySet.contains(parentCompanyId)) {
            return;
        }
        // 获取父级分部、同步数据
        CompPO compPO = getCompMapper().listById(parentCompanyId);
        if (null != compPO) {
            new CompanyTriggerRunnable(compPO, compPO).run();
            refreshCompany(compPO.getParentCompany(), companySet);
        }
        companySet.add(parentCompanyId);
    }

    public static void updateResourceJob(Long jobId) {
        RecordSet rs = new RecordSet();
        rs.executeQuery("select id from cus_fielddata where scope = 'hrmcustomfieldbyinfotype' and scopeid = -1 and field100002 = ?", jobId);
        while (rs.next()) {
            Long resourceId = Long.parseLong(rs.getString("id"));
            new HrmResourceTriggerRunnable(resourceId).run();
        }
    }
}
